<div class="row row-cols-auto justify-content-center"> {% set results = data['data']['results']|selectattr('name_match', '>=', 80)|list %} {% if results %} {% for file in results %} <div class="col m-1 mb-2"> {% include 'components/cardLog.html' %} </div> {% endfor %} {% else %} <div class="col m-1 text-center"><span>No results found</span></div> {% endif %} </div>