abbreviations = {
    'wgp': 'WhenGirlsPlay',
    '18og': '18OnlyGirls',
    '18yo': '18YearsOld',
    '1kf': '1000Facials',
    '21ea': '21EroticAnal',
    '21fa': '21FootArt',
    '21n': '21Naturals',
    '2cst': '2ChicksSameTime',
    'a1o1': 'Asian1on1',
    'aa': 'AmateurAllure',
    'ad': 'AmericanDaydreams',
    'add': 'ManualAddActors',
    'agm': 'AllGirlMassage',
    'am': 'AssMasterpiece',
    'analb': 'AnalBeauty',
    'baebz': 'Baeb',
    'bblib': 'BigButtsLikeItBig',
    'bcasting': 'BangCasting',
    'bconfessions': 'BangConfessions',
    'bglamkore': 'BangGlamkore',
    'bgonzo': 'BangGonzo',
    'brealteens': 'BangRealTeens',
    'bcb': 'BigCockBully',
    'bch': 'BigCockHero',
    'bdpov': 'BadDaddyPOV',
    'bex': 'BrazzersExxtra',
    'bgb': 'BabyGotBoobs',
    'bgbs': 'BoundGangbangs',
    'bin': 'BigNaturals',
    'bjf': 'BlowjobFridays',
    'bp': 'ButtPlays',
    'btas': 'BigTitsatSchool',
    'btaw': 'BigTitsatWork',
    'btc': 'BigTitCreampie',
    'btis': 'BigTitsinSports',
    'btiu': 'BigTitsinUniform',
    'btlbd': 'BigTitsLikeBigDicks',
    'btra': 'BigTitsRoundAsses',
    'burna': 'BurningAngel',
    'bwb': 'BigWetButts',
    'cfnm': 'ClothedFemaleNudeMale',
    'clip': 'LegalPorno',
    'cps': 'CherryPimps',
    'cuf': 'CumFiesta',
    'cws': 'CzechWifeSwap',
    'da': 'DoctorAdventures',
    'Daughter': 'DaughterSwap',
    'Daughters': 'DaughterSwap',
    'dbm': 'DontBreakMe',
    'dc': 'DorcelVision',
    'ddfb': 'DDFBusty',
    'ddfvr': 'DDFNetworkVR',
    'dm': 'DirtyMasseur',
    'dnj': 'DaneJones',
    'dpg': 'DigitalPlayground',
    'dwc': 'DirtyWivesClub',
    'dwp': 'DayWithAPornstar',
    'dsw': 'DaughterSwap',
    'esp': 'EuroSexParties',
    'ete': 'EuroTeenErotica',
    'ext': 'ExxxtraSmall',
    'fams': 'FamilyStrokes',
    'faq': 'FirstAnalQuest',
    'fds': 'FakeDrivingSchool',
    'fft': 'FemaleFakeTaxi',
    'fhd': 'FantasyHD',
    'fhl': 'FakeHostel',
    'fho': 'FakehubOriginals',
    'fka': 'FakeAgent',
    'fm': 'FuckingMachines',
    'fms': 'FantasyMassage',
    'frs': 'FitnessRooms',
    'ft': 'FastTimes',
    'ftx': 'FakeTaxi',
    'gft': 'GrandpasFuckTeens',
    'gbcp': 'GangbangCreampie',
    'gta': 'GirlsTryAnal',
    'gw': 'GirlsWay',
    'h1o1': 'Housewife1on1',
    'ham': 'HotAndMean',
    'hart': 'Hegre',
    'hcm': 'HotCrazyMess',
    'hegre-art': 'Hegre',
    'hoh': 'HandsOnHardcore',
    'hotab': 'HouseofTaboo',
    'ht': 'Hogtied',
    'ihaw': 'IHaveAWife',
    'iktg': 'IKnowThatGirl',
    'il': 'ImmoralLive',
    'kha': 'KarupsHA',
    'kow': 'KarupsOW',
    'kpc': 'KarupsPC',
    'la': 'LatinAdultery',
    'lcd': 'LittleCaprice',
    'lhf': 'LoveHerFeet',
    'lsb': 'Lesbea',
    'lst': 'LatinaSexTapes',
    'lta': 'LetsTryAnal',
    'maj': 'ManoJob',
    'mbb': 'MommyBlowsBest',
    'mbt': 'MomsBangTeens',
    'mc': 'MassageCreep',
    'mcu': 'MonsterCurves',
    'mdhf': 'MyDaughtersHotFriend',
    'mdhg': 'MyDadsHotGirlfriend',
    'mfa': 'ManuelFerrara',
    'mfhg': 'MyFriendsHotGirl',
    'mfhm': 'MyFriendsHotMom',
    'mfl': 'Mofos',
    'mfst': 'MyFirstSexTeacher',
    'mgbf': 'MyGirlfriendsBustyFriend',
    'mgb': 'MommyGotBoobs',
    'mic': 'MomsInControl',
    'mj': 'ManoJob',
    'mlib': 'MilfsLikeItBig',
    'mlt': 'MomsLickTeens',
    'mmgs': 'MommysGirl',
    'mnm': 'MyNaughtyMassage',
    'mom': 'MomXXX',
    'mpov': 'MrPOV',
    'mrs': 'MassageRooms',
    'mshf': 'MySistersHotFriend',
    'mts': 'MomsTeachSex',
    'mvft': 'MyVeryFirstTime',
    'mwhf': 'MyWifesHotFriend',
    'naf': 'NeighborAffair',
    'nam': 'NaughtyAmerica',
    'na': 'NaughtyAthletics',
    'naughtyamericavr': 'NaughtyAmerica',
    'nb': 'NaughtyBookworms',
    'news': 'NewSensations',
    'nf': 'NubileFilms',
    'no': 'NaughtyOffice',
    'nrg': 'NaughtyRichGirls',
    'nubilef': 'NubileFilms',
    'num': 'NuruMassage',
    'nw': 'NaughtyWeddings',
    'obj': 'OnlyBlowjob',
    'otb': 'OnlyTeenBlowjobs',
    'pav': 'PixAndVideo',
    'pba': 'PublicAgent',
    'pf': 'PornFidelity',
    'phd': 'PassionHD',
    'plib': 'PornstarsLikeitBig',
    'pop': 'PervsOnPatrol',
    'ppu': 'PublicPickups',
    'prdi': 'PrettyDirty',
    'ps': 'PropertySex',
    'pud': 'PublicDisgrace',
    'reg': 'RealExGirlfriends',
    'rkp': 'RKPrime',
    'rws': 'RealWifeStories',
    'saf': 'ShesAFreak',
    'sart': 'SexArt',
    'sbj': 'StreetBlowjobs',
    'sislove': 'SisLovesMe',
    'smb': 'ShareMyBF',
    'ssc': 'StepSiblingsCaught',
    'ssn': 'ShesNew',
    'sts': 'StrandedTeens',
    'swsn': 'SwallowSalon',
    'tdp': 'TeensDoPorn',
    'tds': 'TheDickSuckers',
    'ted': 'Throated',
    'tf': 'TeenFidelity',
    'tgs': 'ThisGirlSucks',
    'these': 'TheStripperExperience',
    'tla': 'TeensLoveAnal',
    'tlc': 'TeensLoveCream',
    'tle': 'TheLifeErotic',
    'tlhc': 'TeensLoveHugeCocks',
    'tlib': 'TeensLikeItBig',
    'tlm': 'TeensLoveMoney',
    'togc': 'TonightsGirlfriendClassic',
    'tog': 'TonightsGirlfriend',
    'tspa': 'TrickySpa',
    'tss': 'ThatSitcomShow',
    'tuf': 'TheUpperFloor',
    'wa': 'WhippedAss',
    'wfbg': 'WeFuckBlackGirls',
    'wkp': 'Wicked',
    'wlt': 'WeLiveTogether',
    'woc': 'WildOnCam',
    'wov': 'WivesOnVacation',
    'wowg': 'WowGirls',
    'wy': 'WebYoung',
    'zzs': 'ZZseries',
    'ztod': 'ZeroTolerance',
    'itc': 'InTheCrack',
    'abbw': 'AbbyWinters',
    'abme': 'AbuseMe',
    'ana': 'AnalAngels',
    'atke': 'ATKExotics',
    'atkg': 'ATKGalleria',
    'atkgfs': 'ATKGirlfriends',
    'atkh': 'ATKHairy',
    'aktp': 'ATKPetites',
    'btp': 'BadTeensPunished',
    'brealmilfs': 'Bang.RealMilfs',
    'byngr': 'bang.YNGR',
    'ba': 'Beauty-Angels',
    'bgfs': 'BlackGFS',
    'bna': 'BrandNew',
    'bam': 'BruceAndMorgan',
    'bcast': 'BrutalCastings',
    'bd': 'BrutalDildos',
    'bpu': 'BrutalPickups',
    'cfnmt': 'CFNMTeens',
    'cfnms': 'FNMSecret',
    'cza': 'CzhecAmateurs',
    'czbb': 'CzechBangBus',
    'czb': 'CzechBitch',
    'cc': 'CzechCasting',
    'czc': 'CzechCouples',
    'czestro': 'CzechEstrogenolit',
    'czf': 'CzechFantasy',
    'czgb': 'CzechGangBang',
    'cgfs': 'CzechGFS',
    'czharem': 'CzechHarem',
    'czm': 'CzechMassage',
    'czo': 'CzechOrgasm',
    'czps': 'CzechPawnShop',
    'css': 'CzechStreets',
    'cztaxi': 'CzechTaxi',
    'czt': 'CzechTwins',
    'dlla': 'DadysLilAngel',
    'dts': 'DeepThroatSirens',
    'deb': 'DeviceBondage',
    'doan': 'DiaryOfANanny',
    'dpf': 'DPFanatics',
    'ds': 'DungeonSex',
    'ffr': 'FacialsForever',
    'ff': 'FilthyFamily',
    'fbbg': 'FirstBGG',
    'fab': 'FuckedAndBound',
    'fum': 'FuckingMachines',
    'fs': 'FuckStudies',
    'tfcp': 'FullyClothedPissing',
    'gfr': 'GFRevenge',
    'gdp': 'GirlsDoPorn',
    'hletee': 'HelplessTeens',
    'hotb': 'HouseOfTaboo',
    'Infr': 'InfernalRestraints',
    'inh': 'InnocentHigh',
    'jlmf': 'JessieLoadsMonsterFacials',
    'university': 'KinkUniversity',
    'lang': 'LANewGirl',
    'mmp': 'MMPNetwork',
    'mot': 'MoneyTalks',
    'mbc': 'MyBabysittersClub',
    'mdm': 'MyDirtyMaid',
    'mfp': 'MyFamilyPies',
    'nvg': 'NetVideoGirls',
    'nubp': 'Nubiles-Porn',
    'oo': 'Only-Opaques',
    'os': 'Only-Secretaries',
    'oss': 'OnlySilAndSatin',
    'psus': 'PascalsSubSluts',
    'pbf': 'PetiteBallerinasFucked',
    'phdp': 'PetiteHDPoorn',
    'psp': 'PorsntarsPunishment',
    'pc': 'PrincessCum',
    'pdmqfo': 'QuestForOrgasm',
    'rtb': 'RealTimeBondage',
    'rab': 'RoundAndBrown',
    'sr': 'SadisticRope',
    'sas': 'SexAndSubmission',
    'sed': 'SexualDisgrace',
    'seb': 'SexuallyBroken',
    'sislov': 'SisLovesMe',
    'tslw': 'SlimeWave',
    'steps': 'StepSiblings',
    'stre': 'StrictRestraint',
    't18': 'Taboo18',
    'tft': 'TeacherFucksTeens',
    'tmf': 'TeachMeFisting',
    'tsma': 'TeenSexMania',
    'tsm': 'TeenSexMovs',
    'ttw': 'TeensInTheWoods',
    'tgw': 'ThaiGirlsWild',
    'taob': 'TheArtOfBlowJob',
    'trwo': 'TheRealWorkout',
    'tto': 'TheTrainingOfO',
    'tg': 'TopGrl',
    'tt': 'TryTeens',
    'th': 'TwistysHard',
    'vp': 'VIPissy',
    'wrh': 'WeAreHairy',
    'wpa': 'WhippedAss',
    'yt': 'YoungThroats',
    'zb': 'ZoliBoy',
}
