<span class="badge {{ background_colour }}" {% if tooltip %} data-bs-toggle="tooltip" data-bs-placement="bottom" data-bs-title="{{ tooltip }}" {% endif %}> {{ name }} {% if gender_icon %} <i class="bi bi-{{ gender_icon }}"></i> {% endif %} </span>